/* 
 * (c) Copyright IBM Corp. 2005, 2006. All Rights Reserved. 
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and conditions in the IBM International Program License Agreement. 
 */
package importer;

import java.util.Iterator;

import com.ibm.rational.test.mt.importer.interfaces.IMTAImportSource;
import com.ibm.rational.test.mt.importer.interfaces.IMTAImportSourceConfigSettings;
import com.ibm.rational.test.mt.importer.interfaces.MTANodeKnownProperties;

/**
 * Class called when the user clicks on the finish button in the import wizard
 */
public class ExampleImport implements IMTAImportSource
{
	// Filename from the second page of the import wizard and passed here
	// via the config settings
	String[] filenames = null;
	
	/**
	 * The starting point for the import operation.  This provides an opportunity
	 * to initialize your importer with the configSettings that were created in
	 * the config page addConfigProperties() method (second page of the wizard).
	 * @param cfg parameters
	 * @return 0 on success. -1 on failure.
	 */
	public boolean initialize(IMTAImportSourceConfigSettings cfg)
	{
		// For this example we have have the "file source" property.
		// We will not do anything with it but this shows how to get a property.
		// See ExampleConfigPage.addConfigProperties() to see where and how
		// properties are added.
		String fileSource = (String)cfg.getProperty(MTANodeKnownProperties.PROPERTY_FILESOURCE);
		filenames = new String[] {fileSource};
		
		return true;
	}

	/**
	 * Free all the resources allocated in this class.
	 * @return true=success. false=failure.
	 */
	public boolean destroy()
	{
		// no resources to free
		return true;
	}


	/**
	 * Gets an iterator that will return the Root Node of each 
	 * document to be imported.
	 * @return iterator
	 */
	public Iterator getDocuments( )
	{
		return new ExampleSourceIterator(filenames);
	}

	/**
	 * Get the file to import.
	 */
	public String getCurrentDocumentPath()
	{
		return filenames[0];
	}

	/**
	 * Get the last error occurred.
	 * @return String
	 */
	public String getLastError()
	{
		return null;
	}
}
